@@ -5,19 +5,22 @@ import random
 from subprocess import call
 
 class TicTacToe:
-    def id_generator(self, chars=string.ascii_lowercase + string.digits):
+    def __id_generator(self, chars=string.ascii_lowercase + string.digits):
       return ''.join(random.choice(chars) for x in range(10))
 
     def move_to_server(self,location):
       call("sudo cp /etc/uttt/game_data %s" % (location), shell=True)
 
-    def new(self,player1,player2):
+    def __board(self,player1,player2):
       default_board_layout = {}
       for i in range(11, 100):
         default_board_layout[i] = None
-      if os.stat("game_data")[6]==0:
-        beginning_game_data = { "games" : { player1+','+player2+'1' : { 'id':self.id_generator(), 'player1':player1, 'player2':player2, 'board':default_board_layout, 'current': player1, 'active_square': None, 'move': 0 }}}
-        game_data = json.dumps(beginning_game_data)
+      board = { "games" : { player1+','+player2+'1' : { 'id':self.__id_generator(), 'player1':player1, 'player2':player2, 'board':default_board_layout, 'current': player1, 'active_square': None, 'move': 0 }}}
+      return board
+
+    def new(self,player1,player2):
+      if os.stat("/etc/uttt/game_data")[6]==0:
+        game_data = json.dumps(self.__board(player1,player2))
         raw_game_data = open('/etc/uttt/game_data', 'w')
         raw_game_data.write(game_data+'\n')
         raw_game_data.close()
@@ -56,7 +59,7 @@ class TicTacToe:
           game_data_for_writing = json.dumps(game_data)
           raw_game_data = open('/etc/uttt/game_data', 'w')
           raw_game_data.write(game_data_for_writing+'\n')
-          return "successful"
+          return "%s: %s moved to %s, your turn" % (other_player,speaker,move)
         elif move == '55' and current_game['move'] == 0:
           return "You can't make your first move here!"
         else:
